@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc
 version: 1.16.0.2
-id: pandoc-1.16.0.2-494226a7ccc7fd50f4a9ac5140c1b5f9
-key: pando_KD0dodH93Aq7QtGJZ7kr2v
+id: pandoc-1.16.0.2-1e3210a759893e8cb19c047605eb93fb
+key: pando_CjYCh4RyfaKKGclRmtuBwD
 license: GPL
 copyright: (c) 2006-2015 John MacFarlane
 maintainer: John MacFarlane <jgm@berkeley.edu>
@@ -85,12 +85,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.16.0.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-1.16.0.2
 data-dir: /usr/share/pandoc
-hs-libraries: HSpandoc-1.16.0.2-KD0dodH93Aq7QtGJZ7kr2v
+hs-libraries: HSpandoc-1.16.0.2-CjYCh4RyfaKKGclRmtuBwD
 depends:
     HTTP-4000.3.3-7109897251a899dcae4c73aced404403
     JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
     SHA-1.6.4.2-532d5f478144692bd18b7bfd3a13e191
-    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -110,28 +110,28 @@ depends:
     haddock-library-1.2.1-51a4bfa148b95520f3c56461f9e3c4f2
     highlighting-kate-0.6.1-6cb702a677c14ceb9093e938f2884612
     hslua-0.4.1-5acb63b51e4a9d39e9aa4a0ad9006234
-    http-client-0.4.27-6347f4775f754bcb55a202aff6332b65
-    http-client-tls-0.2.2-4c8e4547ffc0bd404708955d44b21c02
+    http-client-0.4.27-649349307b7fbc2da7ba4e3fdfb27d3d
+    http-client-tls-0.2.2-f98f7df0478363eb3e20cd852c79aa5a
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
-    pandoc-types-1.16.1-9cbefa89bd6c10e54a0cf57a0b477515
+    pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
     parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
+    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
     temporary-1.2.0.4-82bc44ff7d47fd2873d477b044a2a6ac
-    texmath-0.8.4.2-ccfec5cfdf10857fee202173f09a2145
+    texmath-0.8.4.2-d95aec46ca55bfe78645f4742c3c4ff8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-1.3.14-47d6d03c8a900e03cf8951206101564b
-    yaml-0.8.16-fb65281075453c8e8a8a864f3d81487b
+    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
     zip-archive-0.2.3.7-dd493ec9051db44e1b98a11674551a0e
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/pandoc/html/pandoc.haddock
